"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var fft_batch_processor_1 = require("./fft-batch-processor");
var AudioFile = /** @class */ (function () {
    function AudioFile(audioGraph, entireBuffer, bufferSize, numToLinearSmooth) {
        this.signalDataChunked = [];
        this.chunkedFfts = [];
        this.signalDataModifiedChunked = [];
        this.audioGraph = audioGraph;
        this.entireFileAsAudioBuffer = entireBuffer;
        this.bufferSize = bufferSize;
        this.numToLinearSmooth = numToLinearSmooth;
        this.numFullBuffers = Math.floor(entireBuffer.length / this.bufferSize);
    }
    AudioFile.prototype.makeNewChunkedArray = function (processor) {
        var chunkedArr = [];
        for (var i = 0; i < this.numFullBuffers; i++) {
            var arr = new Float32Array(this.bufferSize);
            this.entireFileAsAudioBuffer.copyFromChannel(arr, AudioFile.CHANNEL, i * this.bufferSize);
            chunkedArr.push(processor(arr));
        }
        return chunkedArr;
    };
    AudioFile.prototype.process = function () {
        this.makeSignalDataChunked();
        this.makeSignalDataModifiedChunked();
        this.makeChunkedFfts();
    };
    AudioFile.prototype.makeSignalDataChunked = function () {
        this.signalDataChunked = this.makeNewChunkedArray(function (arr) { return arr; });
    };
    AudioFile.prototype.makeSignalDataModifiedChunked = function () {
        var _this = this;
        var transform = function (arr) {
            var numToReach = arr[0];
            var firstIndex = arr.length - _this.numToLinearSmooth;
            var spacedValues = AudioFile.spaceValues(arr[firstIndex], numToReach, _this.numToLinearSmooth);
            arr.set(spacedValues, firstIndex);
            return arr;
        };
        this.signalDataModifiedChunked = this.makeNewChunkedArray(transform);
    };
    AudioFile.prototype.makeChunkedFfts = function () {
        this.chunkedFfts = fft_batch_processor_1.default.batchFft(this.signalDataChunked);
    };
    AudioFile.spaceValues = function (startValueInclusive, endValueExclusive, valuesToFit) {
        var increment = (endValueExclusive - startValueInclusive) / valuesToFit;
        var returnArr = [];
        for (var i = 0; i < valuesToFit; i++) {
            returnArr.push(startValueInclusive + (increment * i));
        }
        return returnArr;
    };
    AudioFile.CHANNEL = 0;
    return AudioFile;
}());
exports.default = AudioFile;
//# sourceMappingURL=audio-file.js.map