"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var audio_buffer_queue_node_1 = require("./audio-buffer-queue-node");
var types_1 = require("../common/types");
var AudioGraph = /** @class */ (function () {
    function AudioGraph(distributeNewBufferIndex) {
        this.bufferIndex = 0;
        this.readOnlyIsLooping = false;
        this.audioContext = new AudioContext();
        this.distributeNewBufferIndex = distributeNewBufferIndex;
    }
    AudioGraph.prototype.buildNodes = function (audioFile) {
        this.gainNode = this.audioContext.createGain();
        this.oscillatorNode = this.audioContext.createOscillator();
        this.specialNode = new audio_buffer_queue_node_1.default(this, audioFile);
    };
    AudioGraph.prototype.connectNodes = function () {
        this.specialNode.connect(this.gainNode);
        this.gainNode.connect(this.audioContext.destination);
        return types_1.AudioGraphStatus.Connected;
    };
    AudioGraph.prototype.resetGraphToDefaultState = function () {
        this.bufferIndex = 0;
        return this.disconnectAllNodes();
    };
    AudioGraph.prototype.disconnectAllNodes = function () {
        if (this.gainNode)
            this.gainNode.disconnect();
        if (this.specialNode)
            this.specialNode.disconnect();
        if (this.oscillatorNode)
            this.oscillatorNode.disconnect();
        return types_1.AudioGraphStatus.Disconnected;
    };
    AudioGraph.prototype.updateBufferIndex = function (increment, audioFile) {
        var wouldBeOutOfRange = (this.bufferIndex + increment < 0) || (this.bufferIndex + 1 + increment >= audioFile.numFullBuffers);
        if (wouldBeOutOfRange) {
            this.bufferIndex = audioFile.numFullBuffers - 2;
            this.distributeNewBufferIndex(this.bufferIndex);
            this.disconnectAllNodes();
            return;
        }
        if (this.bufferIndex < 0)
            this.bufferIndex = 0;
        if (this.bufferIndex + 1 >= audioFile.numFullBuffers)
            this.disconnectAllNodes();
        this.bufferIndex += increment;
        this.distributeNewBufferIndex(this.bufferIndex);
    };
    AudioGraph.prototype.getBufferIndex = function () {
        return this.bufferIndex;
    };
    AudioGraph.prototype.setReadOnlyIsLooping = function (isLooping) {
        this.readOnlyIsLooping = isLooping;
    };
    AudioGraph.BUFFER_SIZE = 2048;
    return AudioGraph;
}());
exports.default = AudioGraph;
//# sourceMappingURL=audio-graph.js.map