"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var React = require("react");
var file_loader_1 = require("./file-loader/file-loader");
var visualization_1 = require("./visualization/visualization");
var audio_file_1 = require("./audio-engine/audio-file");
var audio_graph_1 = require("./audio-engine/audio-graph");
var navigation_1 = require("./navigation/navigation");
var types_1 = require("./common/types");
var FFTFlipBook = /** @class */ (function (_super) {
    __extends(FFTFlipBook, _super);
    function FFTFlipBook(props) {
        var _this = _super.call(this, props) || this;
        _this.updateReadOnlyBufferIndex = function (newIndex) {
            _this.setState({ readOnlyBufferIndex: newIndex });
        };
        _this.handleTogglePlay = function () {
            switch (_this.state.audioGraphStatus) {
                case types_1.AudioGraphStatus.Disconnected:
                    return _this.setState({ audioGraphStatus: _this.state.audioGraph.connectNodes() });
                case types_1.AudioGraphStatus.Connected:
                    return _this.setState({ audioGraphStatus: _this.state.audioGraph.disconnectAllNodes() });
            }
        };
        _this.handleResetGraphToDefaultState = function () {
            _this.updateReadOnlyBufferIndex(0);
            _this.state.audioGraph.resetGraphToDefaultState();
            _this.setState({ audioGraphStatus: types_1.AudioGraphStatus.Disconnected });
        };
        _this.handleLoadFile = function (file) {
            console.log('file', file);
            _this.setState({ audioFileStatus: types_1.AudioFileStatus.Loading });
            var audioGraph = _this.state.audioGraph;
            _this.handleResetGraphToDefaultState();
            audioGraph.audioContext.decodeAudioData(file, function (buffer) {
                var audioFile = new audio_file_1.default(_this.state.audioGraph, buffer, audio_graph_1.default.BUFFER_SIZE, 0);
                _this.audioFile = audioFile;
                audioFile.process();
                audioGraph.buildNodes(audioFile);
                _this.setState({ audioFileStatus: types_1.AudioFileStatus.Ready });
            });
        };
        _this.handleToggleIsLooping = function () {
            var newIsLooping = !_this.state.isLooping;
            _this.state.audioGraph.setReadOnlyIsLooping(newIsLooping);
            _this.setState({ isLooping: newIsLooping });
        };
        _this.renderButtonsAndDropzone = function () {
            var _a = _this.state, audioGraph = _a.audioGraph, normalVisualizationStyle = _a.normalVisualizationStyle, audioFileStatus = _a.audioFileStatus;
            var fileLoader = React.createElement(file_loader_1.default, { key: 1, canLoadFile: audioGraph !== null && audioFileStatus !== types_1.AudioFileStatus.Loading, handleLoadFile: _this.handleLoadFile, normalVisualizationStyle: normalVisualizationStyle });
            var visualStyleChanger = React.createElement("button", { className: "ffb-button " + (normalVisualizationStyle ? 'ffb-styleChanger-topRight' : 'ffb-styleChanger-bottomLeft'), key: 2, onClick: function () { return _this.setState({ normalVisualizationStyle: !_this.state.normalVisualizationStyle }); } }, normalVisualizationStyle ? 'Circle' : 'Normal');
            var navigation = React.createElement(navigation_1.default, { key: 3, audioFileStatus: audioFileStatus, audioGraphStatus: _this.state.audioGraphStatus, handleIncrement: function (num) { return audioGraph.updateBufferIndex(num, _this.audioFile); }, togglePlay: _this.handleTogglePlay.bind(_this), isLooping: _this.state.isLooping, toggleIsLooping: _this.handleToggleIsLooping.bind(_this), normalVisualizationStyle: _this.state.normalVisualizationStyle, readOnlyBufferIndex: _this.state.readOnlyBufferIndex });
            return normalVisualizationStyle
                ? React.createElement("div", null, [navigation, fileLoader, visualStyleChanger])
                : React.createElement("div", null, [visualStyleChanger, fileLoader, navigation]);
        };
        _this.state = {
            audioGraph: null,
            readOnlyBufferIndex: 0,
            audioFileStatus: types_1.AudioFileStatus.Uninitiated,
            audioGraphStatus: types_1.AudioGraphStatus.Disconnected,
            normalVisualizationStyle: true,
            isLooping: false
        };
        return _this;
    }
    FFTFlipBook.prototype.componentDidMount = function () {
        var audioGraph = new audio_graph_1.default(this.updateReadOnlyBufferIndex.bind(this));
        this.setState({ audioGraph: audioGraph });
    };
    FFTFlipBook.prototype.render = function () {
        var spectrum = this.audioFile ? this.audioFile.chunkedFfts[this.state.audioGraph.getBufferIndex()] : new Float32Array([]);
        if (!this.state.audioGraph) {
            return (React.createElement("div", null, "loading audio graph"));
        }
        return (React.createElement("div", { className: "ffb", style: { width: this.props.width + "px", height: this.props.height + "px" } },
            React.createElement(visualization_1.default, { spectrum: spectrum, width: this.props.width, height: this.props.height, normalVisualizationStyle: this.state.normalVisualizationStyle }),
            this.renderButtonsAndDropzone()));
    };
    return FFTFlipBook;
}(React.Component));
exports.default = FFTFlipBook;
//# sourceMappingURL=react-fft-flipbook.js.map