"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var React = require("react");
var react_konva_1 = require("react-konva");
var helpers_1 = require("../common/helpers");
var FlipBook = function (props) {
    var spectrumAsNormalArr = Array.prototype.slice.call(props.spectrum);
    var spectrumLength = spectrumAsNormalArr.length;
    var getPointsForSpectrumAsCircle = function () {
        var centerPoint = { x: props.width / 2, y: props.height / 2 };
        var angleIncrement = (1 / spectrumLength) * 2 * Math.PI;
        var closestWall = (props.width > props.height)
            ? props.height / 2
            : props.width / 2;
        var minimumCircleRadius = 0.1 * closestWall;
        var multiplier = 0.018 * closestWall;
        var currentAngle = 0;
        return spectrumAsNormalArr.map(function (value) {
            var hypotenuse = (value * multiplier) + minimumCircleRadius;
            var x = centerPoint.x + hypotenuse * Math.sin(currentAngle);
            var y = centerPoint.y + hypotenuse * Math.cos(currentAngle);
            currentAngle += angleIncrement;
            return { x: x, y: props.height - y };
        });
    };
    var getPointsForSpectrumAsLine = function () {
        var distanceBetweenEachPoint = props.width / spectrumLength;
        var x = 0;
        var multiplier = props.height / 50;
        return spectrumAsNormalArr.map(function (value) {
            x += distanceBetweenEachPoint;
            return { x: x, y: props.height - (value * multiplier) };
        });
    };
    var points = props.normalVisualizationStyle
        ? getPointsForSpectrumAsLine()
        : getPointsForSpectrumAsCircle();
    return (React.createElement(react_konva_1.Stage, { className: "ffb-visualization", width: props.width, height: props.height },
        React.createElement(react_konva_1.Layer, null,
            React.createElement(react_konva_1.Line, { points: helpers_1.transformArrayOfPointsToKonvaPointArray(points), stroke: 'black', shadowBlur: 2 }))));
};
exports.default = FlipBook;
//# sourceMappingURL=visualization.js.map